# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Provides/Requires filtering is different from rpm 4.9 onwards
%global rpm49 %(rpm --version | perl -p -e 's/^.* (\\d+)\\.(\\d+).*/sprintf("%d.%03d",$1,$2) ge 4.009 ? 1 : 0/e' 2>/dev/null || echo 0)

Name:		perl-Class-XSAccessor
Version:	1.19
Release:	19.%{__distinit}%{__distvers}
Summary:	Generate fast XS accessors without run-time compilation
License:	GPL+ or Artistic
URL:		https://metacpan.org/release/Class-XSAccessor
Source0:	https://cpan.metacpan.org/modules/by-module/Class/Class-XSAccessor-%{version}.tar.gz
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Run-time:
BuildRequires:	perl(Carp)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Tests:
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(threads)
BuildRequires:	perl(Time::HiRes)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't "provide" private Perl libs
%global __provides_exclude ^XSAccessor\\.so

# Do not require private module (rpm ≥ 4.9)
%global __requires_exclude ^perl\\(Class::XSAccessor::Heavy\\)

%description
Class::XSAccessor implements fast read, write and read/write accessors in
XS. Additionally, it can provide predicates such as has_foo() for testing
whether the attribute foo is defined in the object. It only works with
objects that are implemented as ordinary hashes. Class::XSAccessor::Array
implements the same interface for objects that use arrays for their
internal representation.

%prep
%setup -q -n Class-XSAccessor-%{version}

# Do not require private module (rpm < 4.9)
%if ! %{rpm49}
%global perl_reqfilt /bin/sh -c "%{__perl_requires} | grep -Fvx 'perl(Class::XSAccessor::Heavy)'"
%define __perl_requires %{perl_reqfilt}
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README
%{perl_vendorarch}/auto/Class/
%{perl_vendorarch}/Class/
%{_mandir}/man3/Class::XSAccessor.3*
%{_mandir}/man3/Class::XSAccessor::Array.3*
%{_mandir}/man3/Class::XSAccessor::Heavy.3*

%changelog
* Sat Nov 16 2019 Paul Howarth <paul@city-fan.org> - 1.19-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.19-18
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.19-15
- Perl 5.28 rebuild

* Tue Aug  8 2017 Paul Howarth <paul@city-fan.org> - 1.19-13
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun  4 2017 Paul Howarth <paul@city-fan.org> - 1.19-11
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 1.19-9
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Fri Sep 18 2015 Paul Howarth <paul@city-fan.org> - 1.19-5
- Explicitly BR: perl-devel, needed for EXTERN.h

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.19-4
- Perl 5.20 rebuild

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 1.19-2
- Import from Fedora

* Tue Nov 26 2013 Petr Pisar <ppisar@redhat.com> - 1.19-1
- 1.19 bump

* Sat Aug  3 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.18-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.18-2
- Perl 5.18 rebuild

* Thu Jun 20 2013 Petr Šabata <contyk@redhat.com> - 1.18-1
- 1.18 bump

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Dec  3 2012 Jitka Plesnikova <jplesnik@redhat.com> - 1.16-1
- 1.16 bump
- Replace PERL_INSTALL_ROOT with DESTDIR
- Add BR perl(Carp)

* Fri Aug 31 2012 Petr Šabata <contyk@redhat.com> - 1.14-1
- 1.14 bump (no changes for Fedora)
- Drop command macros

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.13-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jun 11 2012 Petr Pisar <ppisar@redhat.com> - 1.13-3
- Perl 5.16 rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Dec 12 2011 Petr Šabata <contyk@redhat.com> - 1.13-1
- 1.13 bump
- Remove BuildRoot and defattr
- Remove ::Array self-obsolete

* Mon Sep  5 2011 Petr Sabata <contyk@redhat.com> - 1.12-1
- 1.12 bump

* Fri Jul 22 2011 Petr Pisar <ppisar@redhat.com> - 1.11-4
- RPM 4.9 dependency filtering added

* Tue Jun 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.11-3
- Perl mass rebuild

* Tue Feb  8 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec  9 2010 Petr Sabata <psabata@redhat.com> - 1.11-1
- New upstream release, v1.11

* Fri Dec  3 2010 Petr Sabata <psabata@redhat.com> - 1.10-1
- New upstream release, v1.10

* Mon Nov  8 2010 Petr Sabata <psabata@redhat.com> - 1.09-1
- New upstream release, v1.09

* Wed Sep 29 2010 jkeating - 1.08-3
- Rebuilt for gcc bug 634757

* Mon Sep 20 2010 Petr Pisar <ppisar@redhat.com> - 1.08-2
- Do not require private perl(Class::XSAccessor::Heavy)
- Correct Summary spelling
- Enable tests

* Mon Sep 20 2010 Petr Sabata <psabata@redhat.com> - 1.08-1
- New upstream release, v1.08

* Thu Sep  2 2010 Petr Sabata <psabata@redhat.com> - 1.07-1
- New upstream release, v1.07

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.05-5
- Mass rebuild with perl-5.12.0

* Tue Dec 22 2009 Marcela Mašláňová <mmaslano@redhat.com> - 1.05-4
- Rebuild with obsoletes in spec

* Tue Dec 22 2009 Marcela Mašláňová <mmaslano@redhat.com> - 1.05-3
- Class::XSAccessor::Array became a part of this package - fixes conflict of man

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.05-2
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.03-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jun 19 2009 Stepan Kasal <skasal@redhat.com> - 1.03-2
- Rebuild with AutoXS::Header 1.02

* Mon Jun  1 2009 Marcela Mašláňová <mmaslano@redhat.com> - 1.03-1
- Update

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 15 2008 Marcela Mašláňová <mmaslano@redhat.com> - 0.14-1
- Update to 0.14

* Fri Dec  5 2008 Marcela Mašláňová <mmaslano@redhat.com> - 0.11-1
- Specfile autogenerated by cpanspec 1.77
